California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 001 - SCA 10 (RESOLUTION CHAPTER 97, STATUTES OF 2022) ATKINS. REPRODUCTIVE FREEDOM. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1451868 | WOMEN FOR REPRODUCTIVE FACTS- NO ON PROP 1 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1357909 | ATKINS BALLOT MEASURE COMMITTEE; YES ON PROPOSITION 1, SUPPORTED BY HEALTH CARE ORGANIZATIONS, PLANNED PARENTHOOD AFFILIATES OF CALIFORNIA AND SENATOR TONI | SUPPORT